      Program assignj_17

!     Date: 2/07/2001
              
!     For each household and individual in the SAR, values of j are
!     calculated for every table under consideration.
!     Household results are written out to the file
!     ../Sar/HJ.sar,
!     the individual results to
!     ../Sar/IJ.sar

!*    17 Tables (I - individual characteristics, H - household characteristics)                                            
!*      1.  2.   3.  4.  5.  6.  7.   8.  9.  10. 11. 12. 13. 14. 15. 16.  17.
!*      S35 S42a S01 S22 S14 S29 S74a S86 S39 S34 S08 S49 S06 S09 S43 S42b S74b
!*      I   H    I   H   I   H   I    H   I   I   I   H   I   I   H   H    I

!     The exact contents of the two output files are as follows:

!     HJ.sar

!     H13 H28 j(2) j(4) j(6) j(8) j(12) j(15) j(16)                                  !*

!     where j(2), j(4), j(6) J(8) j(12) j(15) j(16)    are values of j for tables 
!     2,4,6,8,12,15 and H13 and H28 are the PersInHH and FirstInd of the household

!     IJ.sar

!      j(1) j(3) j(5) j(7) j(9) j(10) j(11) j(13) j(14) j(17)                        !*

!     they are values of j for tables 1,3,5,7,9,10,11,13,14,17                     !*

!     parameter declarations follow

      character*50 FName(1:10)

!     FName(I) links channel I in read and write statements to a file
!     with the name FName(i), as read in by the sub-routine FNames

!*    17 tables have 26 variables in total 

!      integer D(0:16,1:8)  
      integer D(0:26,1:17)

!     D(k,m) represents the set of Kronecker deltas for each derived
!     variable, 1..k, for each table, 1..NoofT, whilst D(0,m) = no. of
!     cells in table vector, Nm

!      integer C(1:16) 
      integer C(1:26)

!     C(k) represents the number of categories into which the derived
!     attribute k is divided

!      integer Nm(1:8)
      integer Nm(1:17) 
      
!     Base(m) holds a record of the fixed population constraint used
!     for table m in the 'normalization' of Ujm and Tjm

!*      integer U(0:196,1:8)
!*      integer T(0:196,1:8)
      integer U(0:198,1:17)
      integer T(0:198,1:17) 
      
!     U(j,m) is the table vector containing SASPAC91 data in cells
!     1,..,j,..Nm for each SAS/LBS table, m.  U(0,m) = table total.
!     T(j,m) is the equivalent table vector, found by 'tabulation'
!     of SAR household data

!*      integer V(1:16,0:999) 
      integer V(1:26,0:999)

!     V(k,k1) contains the index which allows matching of a category
!     in base variable k1 with a category in derived attribute k
!     0:99 (k1) is the maximum extent of categories in k2, being 
!     single year of age 0 to 99+.  All other base variables have
!     fewer categories than this (Although see occpatn...).

!*      integer metaV(1:16)
      integer metaV(1:26)

!     metaV(k) contains the index with allows the matching of
!     derived variable k with a base variable, k1

!*      integer lBV(1:16), uBV(1:16)
      integer lBV(1:26), uBV(1:26)

!     lBV(k) represents the lowest valid value of base attribute k,
!     whilst uBV(k) represents the uppermost valid value.

!*      integer B1(1:68), B2(1:16) 
      integer B1(1:70), B2(1:26)      

!     B1 and B2 are buffers used to store an individuals base attribute
!     values (B1) and derived attribute equivalent values (B2) for
!     table m in CalcTjm().  Note: The first 28 cells in B1 
!     store information concerning the household from which the
!     individual is drawn (i.e. the hhold record part of the hhold SAR)

!*      integer agesex(1:8)
      integer agesex(1:17) 
      
!     agesex records the variable number of any gender differentiated
!     age variable (one containing the term pensionable age), for each
!     table being processed.

!*      integer H(1:215789,1:8), I(1:541894,1:8)
      integer H(1:215789,1:17), I(1:541894,1:17)      

!     H records the value of j assigned to each household for a table
!     I records the value of j assigned to each individual for a table

      integer Comb(1:200)

!     Comb records the combination of households currently being
!     evaluated

!      integer lnblnk

!     typing of function lnblnk()

      integer Nooft,nooff,NoOfH,MaxH,NoOfV,NoOfBV,NoOfXBV, &
        MaxJ,MinC,MaxC,SarSize,m,j,hhno,ind,noofi,table

      MAXH=200
!*      NOOFT=8 
      NOOFT=17                       
      NOOFF=10
!*      NOOFV=16                     
      NOOFV=26                        
      NOOFBV=65
!*      NOOFXBV=68
      NOOFXBV=70
!*      MAXJ=196
      MAXJ=198
      MINC=0
      MAXC=999
      SARSIZE=215789
      NOOFI=541894

!     MaxH = maximum no. of households possible in spatial unit (ED)
!     NoOfF = no. of files in Pop91.filelist
!     NoOfH = number of households in spatial unit (ED)
!     NoOfT = no. of tables used to constrain SAR
!     NoOfV = no. of derived attributes
!     NoOfBV = no. of base attributes (as in processed SAR)
!     NoOfXBV = no. of extended base attributes (not in MetaC91)
!     NoOfI= no. of individuals in sample population file
!     MaxJ = largest possible value of Nm
!     MinC = lowest value of any base variable (Age)
!     MaxC = highest value of any base variable (Industry)
!     SarSize=number of households in SAR
!     NoOfI = number of individuals in SAR
!     m = current LBS/SAS table being considered (loop counter)
!     j = table vector counter
!     hhno = household counter
!     TAE = Total Absolute Error

        write (5,*) "1. assignj begin"          !* NOTE: screen channel 5,6 not *
        
!     Read in filenames for linkage to read/write statements

      call fnames(fname,nooff)

!     open channel 1 for input from hh.sar - hhold recs from hhold SAR
!     open channel 2 for input from hhind.sar - Ind recs from hhold SAR
!     open channel 8 for programme household output (HJ.sar)
!     open channel 9 for programme individual output (IJ.sar)

        write (5,*) "2. call fnames completed"   
 
      open(1,file=fname(1),access='direct', &
           status='old',form='formatted',recl=62)
      open(2,file=fname(2),access='direct', &
           status='old',form='formatted',recl=72)
        
!     open output channels, as defined in assignj.filelist

      open(8,file=fname(8))
      open(9,file=fname(9))

!      open(8,file='/home/jge/william/Sar/HJ.sarnew')
!      open(9,file='/home/jge/william/Sar/IJ.sarnew')

!     Read in the no. of derived variable for each base attribute, C(s)
!     the table vector size (Nm) and the relevant string of Kronecker
!     Deltas (D) for each table, m
!      write(6,*) 'about to call deltas'
      
        write (5,*) "3. open inpute/output channels completed" 

      call deltas(C,D,nooft,nooff,noofv,fname)
!      write(6,*) 'leaving deltas'
!     Nm(m) = D(0,m) (inefficient but avoids clash with pop91.f)

      do 10, table=1,nooft
         Nm(table)=D(0,table)
 10   continue

!     Read in the meta-index mapping derived variables to base
!     attributes, metaV, the index mapping a derived variable
!     category with its base attribute equivalent, V, and the
!     highest and lowest valid values of base attribute k,
!     uBV and lBV. 

        write (5,*) "4. call daltas completed" 

      call indexes(metaV,V,lBV,uBV,noofv,fname,nooff,minC,maxC)

!     Read in variable numbers of gender differentiated age vars.

        write (5,*) "5. call indexes completed" 
        
      call readagsx(agesex,nooft,fname,nooff)

!     Read in all SAS table data used as population estimate
!     constraints     

      call readujm(U,Nm,nooft,fname,nooff,maxj,noofh) 
      
        write (5,*) "6. call readagsx and readujm completed" 
!     Find a value of j for each household for each table.  Results
!     stored in H(j,m) and I(j,m)
        
        write (5,*) "7. call findtjm - two more minutes to go"
        
      call FindTjm(T,metaV,V,fname,nooff,noofbv,noofxbv,noofv,nooft, &
      C,D,B1,B2,noofh,maxj,MaxH,hhno,j,SarSize,ind,U,Comb, &
      minC,maxC,H,I,noofi,m,agesex)

      stop
      end
