      Program PrepData_17

!     Date: 11/07/2001    

!     This program reads in SAS tables extracted in 'matrix' style
!     format using SASPAC91, and writes out tabulations used as
!     constraints in Pop91/Agape etc. in an appropriate format (i.e.
!     alphabetically order - age by marstatt by sex, NOT age by sex by
!     marstatt)

!*      Total number of tables: 17 

!**     SAS86&74 use data created by Pop91SR (synthetic reconstruction approach)
!       file name:  /data/sas/sas86_5.dat and sas74_5.dat (averag of 5 runs)
!       the ED sequence in sas86_5.dat & sas74_5.dat must be the same as pop91_17.fmt
!       ckeck can be done by looking the final line of each output files

!***    Adjust those tables including residents-not-in-households (S06,S08,S09)
!       1) no. of residents is given by T01(65) 
!          no. of residents aged 16+ is given by T34(1)
!       2) S06,S08,S09: where the no. of residents (or residents aged 16+) 
!          (table sum) is large than the no. of residents in household (or 
!          aged 16+ resicdents in household), the table is scaled down
!          to meet the desired toatl (keeping the same distribution) and then 
!          randomly rounded to integer counts.
!       3) subroutine Rounding_MC: is added for the purpose.  

!****   All outputs are in the folder /data/sas
!        including edcode.dat - each ED
!                  wdcodeT86.dat and wdcodeT74.dat - aggregated ward table 86&74
 
!     Tabulations processed are (in order):

!     1) S35:   Age by MarStatt by Sex
!     2) S42a:  Tenure by HHComp
!     3) S01:   Residsta by Sex 
!     4) S22:   PersInHH by RoomsNum by Tenure 
!     5) S14:   Age by EconPrim by LtIll 
!     6) S29:   HHComp (DepNoP by NDepNo) 
!     7) S74a:   Age by Occpatn by Sex
!     8) S86:   Tenure by SEG of HOH 
!*    9)  S39:   Age by MarStatt by Sex of HOH 
!*    10) S34:   MarStatt by Sex by EconPrim
!*    11) S08:   Age by Sex by EconPrim        
!*    12) S49:   EthGroup by Tenure
!*    13) S06:   Age by EthGroup 
!*    14) S09:   EconPrim by EthGroup by sex
!*    15) S49:   EthGroup of HOH by HHcomp
!*    16) S42b   Car by HHComp                         
!*    7) S74b:   Occpatn by Sex (drop age group in table 74)             

      integer T35(1:154),T42(1:256),T01(1:70),T22(1:405)
      integer T14(1:78),T29(1:64),T74(1:110),T86(1:299)
      integer T39(1:56),T34(1:84),T08(1:308),T49(1:84)                         !*
      integer T06(1:108),T09(1:54),T43(1:24)                                   !* 
           
      integer A1(1:21,1:2,1:2),A2(1:7,1:11),A3(1:3,1:2),A4(1:7,1:7,1:4)
      integer A5(1:4,1:10), A7(1:5,1:10,1:2), A8(1:4,1:19),SumA8(1:4,1:19)  
      integer A9(7,2,2),A10(11,2,2),A11(9,11,2),A12(4,4)                                       !* 
      integer A13(5,10),A14(3,4,2),A15(4,2),A16(3,11), A17(10,2)
      integer Atemp(1:16,1:11)          
      
      integer Tjm35(1:84), Tjm42(1:77), Tjm01(1:6),Tjm22(1:196)
      integer Tjm14(1:40), Tjm29(1:7), Tjm74(1:100),Tjm86(1:76)         !*
      integer Tjm39(1:28), Tjm34(1:44), Tjm08(1:198)                   !* maxj=198     
      integer Tjm49(1:16), Tjm06(1:50), Tjm09(1:24), Tjm43(1:8)
      integer Tjm42b(1:33), Tjm74b(1:20)
            
      integer cell, noofh,tothh,Stub,total,N,temp,noofv,newtot
      real    prop
      character*6 edcode,edid                                                   !**
      integer Age,Sex,MarStatt,Tenure,HHComp,ResidSta,PersInHH,RoomsNum
      integer EconPrim,Occpatn,SEGHOH,lineno, Car
      integer EthGroup                                                         !*
      real RTjm86(1:76) 
      integer WardTjm86(1:76),WardTjm74(1:20),Nk, Aggnoofh, noofed
      character*4 wdcode1,wdcode2      
      WardTjm86=0; WardTjm74b=0
      
!*    replace c:\Project with e:\Pop91t17

      ! input files (note all SAS data for Pop91_17 are in dir: 
      !             \Data\SAS  not in \Data)
      
      open(8,file='e:\Pop91t17\Data\SAS\pop91_17.fmt',status='old')
!*
      open(5,file='e:\Pop91t17\Data\SAS\sas86_5.dat',status='old') 
      open(15,file='e:\Pop91t17\Data\SAS\sas74_5.dat',status='old')
!*      
      ! output files
      open(4,file='e:\Pop91t17\Data\EDlist')
      open(3,file='e:\Pop91t17\Data\WDlist',status='replace')
      
!      open later
!      open(6,file='e:\Pop91t17\Data\SAS\'//edcode//'.dat',status='replace')
!      channels 7 and 9 for output ward table 86 and 74 (aggregated ED tables) 

        Nk=1                    
        wdcode1='abcd'
        noofed=0
        
  1   read(8,'(a6)',end=999) edcode
        
!        noofed=noofed+1
        wdcode2(1:4)=edcode(1:4) 
          
        if (wdcode2 /= wdcode1 .and. wdcode1 /='abcd') then
                
            ! agg. ED table 86&74 to ward level (for ward level comperison)
            open(7,file='e:\Pop91t17\Data\SAS\'//wdcode1//'T86.dat',status='replace') !*    
            
            write(7,'(19i6)') (wardTjm86(cell),cell=1,76)   
            write(7,*) wdcode1  
            wardTjm86=0
                          
            open(9,file='e:\Pop91t17\Data\SAS\'//wdcode1//'T74.dat',status='replace')  !*                             

            write(9,'(2i8)') (wardTjm74(cell),cell=1,20)
            write(9,*) wdcode1            
            wardTjm74=0
                    
            ! output WDlist
            write(3,'(a4,i10)') wdcode1, noofed-1
            noofed=1           
        endif
        
!      do 5, N=1,4
!         temp=ichar(edcode(N:N))
!         edcode(N:N)=char(temp+32)
! 5    continue

!     0.  Read in no. of households.  If ED contains households
!     then open output files and proceed with data processing.
!     Otherwise, skip on to next ED.

!     read numbers of households and 
!     persons in visitor households
      read(8,'(2i4)') noofh, noofv

      read(8,'(20i4)') (T35(cell), cell=1,154)
      read(8,'(20i4)') (T42(cell), cell=1,256)
      read(8,'(20i4)') (T01(cell), cell=1,70)
      read(8,'(20i4)') (T22(cell), cell=1,405)
      read(8,'(20i4)') (T14(cell), cell=1,78)
      read(8,'(20i4)') (T29(cell), cell=1,64)
      read(8,'(20i4)') (T74(cell), cell=1,110)
      read(8,'(20i4)') (T86(cell), cell=1,299)
!*
      read(8,'(20i4)') (T39(cell), cell=1,56)
      read(8,'(20i4)') (T34(cell), cell=1,84)
      read(8,'(20i4)') (T08(cell), cell=1,308)
      read(8,'(20i4)') (T49(cell), cell=1,84) 
      read(8,'(20i4)') (T06(cell), cell=1,108)
      read(8,'(20i4)') (T09(cell), cell=1,54)      
      read(8,'(20i4)') (T43(cell), cell=1,24)
     
! Read through ED if no households present
! ** Number of lines to be read through will vary if table
! ** constraints changed 

!      if (noofh .eq. 0) then
!        do 7,lineno=1,75+3                                                      !*
!          read(8,*)
! 7      continue   
!      endif

      if (noofh .eq. 0) goto 1
!
        noofed=noofed+1 
        
      write(*,*) edcode
        
      open(6,file='e:\Pop91t17\Data\SAS\'//edcode//'.dat',status='replace')

!     0.  Read in Table matrices as Table vectors (buffers)

      write(4,'(a6)') edcode
      write(6,'(i8)') noofh
       
!     1.  Convert T35 into A1(Age,MarStatt,Sex) and then into Tjm35

      cell=7
      do 10, Age=1,21
         cell=cell+1
         do 20, Sex=1,2
            cell=cell+1
            do 30, MarStatt=1,2
               cell=cell+1
               A1(Age,MarStatt,Sex)=T35(cell)
 30         continue
 20      continue
 10   continue

      cell=0
      do 40,Age=1,21
         do 50, MarStatt=1,2
            do 60, Sex=1,2
               cell=cell+1
               Tjm35(cell)=A1(Age,MarStatt,Sex)
 60         continue
 50      continue
 40   continue 

!      write(6,'(i8)') T35(1) 
                  write(6,'(i8)') Sum(Tjm35(1:84))
      write(6,'(4i8)') (Tjm35(cell), cell=1,84)

!     2.  Convert T42 into A2(Tenure,HHComp) and then into Tjm42

!      TotHH=0
!      do 70, cell=8,14
!         TotHH=TotHH+T42(cell)
! 70   continue
!      write(6,'(i8)') TotHH

      cell=16
      do 80,HHComp=1,11
         cell=cell+7
         do 90,Tenure=1,7
            cell=cell+1
            A2(Tenure,HHComp)=T42(cell)
 90      continue
         cell=cell+2
 80   continue

      cell=0
      do 100, Tenure=1,7
         do 110, HHComp=1,11
            cell=cell+1
            Tjm42(cell)=A2(Tenure,HHComp)
 110     continue
 100  continue  
 
                  write(6,'(i8)') Sum(Tjm42(1:77))
      write(6,'(4i8)') (Tjm42(cell), cell=1,77)   
      

!     3.  Convert T01 into A3(ResidSta,Sex) and then into Tjm01

      do 115, ResidSta=1,3
         do 117, Sex=1,2
            A3(ResidSta,Sex)=0
 117     continue
 115  continue

      cell=0
      do 120, Stub=1,5
         if (Stub .eq. 1) ResidSta=1
         if ((Stub .gt. 1) .and. (Stub .lt. 5) ) ResidSta=2
         if (Stub .eq. 5) ResidSta=3
            cell=cell+2
            do 130, Sex=1,2
               cell=cell+1
               A3(ResidSta,Sex)=A3(ResidSta,Sex)+T01(cell)
 130        continue
            cell=cell+3
 120  continue

      cell=0
      do 160,ResidSta=1,3
         do 170, Sex=1,2
            cell=cell+1
            Tjm01(cell)=A3(ResidSta,Sex)
 170     continue
 160  continue

!     subtract persons in visitor households 
!       from two sexes in equal proportions 
      total=Tjm01(5)+Tjm01(6)
      newtot=total-noofv
!-------------------------------
        if(newtot < 0) newtot=0     ! it happens (dagb13,dagb04)
!-------------------------------              
      
      if (total.gt.0) prop=real(Tjm01(5))/real(total)
      Tjm01(5)=anint(prop*newtot)
      Tjm01(6)=newtot-Tjm01(5)
                                                                                             
!      write(2,'(i8)') T01(10),t01(11),T01(17),T01(18),T01(24),T01(25)

      total=0
      do 180, cell=1,6
         total=total+Tjm01(cell)
 180  continue     
 
      do cell=1,6 
        if (Tjm01(cell) < 0) then
        write(*,*)'edcode,cell,T01<0',edcode,cell,Tjm01(cell)
        stop
        endif
      enddo
!      write(6,'(i8)') total 
            write(6,'(i8)') Sum(Tjm01(1:6))
      write(6,'(4i8)') (Tjm01(cell), cell=1,6)

!     4.  Convert T22 into A4(PersInHH,RoomsNum,Sex) and then into Tjm22

      cell=81

      do 190, Tenure=1,4

         cell=cell+9
      
         do 200, PersInHH=1,7
            cell=cell+1

            do 210, RoomsNum=1,7
               cell=cell+1
               A4(PersInHH,RoomsNum,Tenure)=T22(cell)
 210        continue
            cell=cell+1
 200     continue

         cell=cell+9

 190  continue

      cell=0
      do 220, PersInHH=1,7
         do 230, RoomsNum=1,7
            do 240, Tenure=1,4
               cell=cell+1
               Tjm22(cell)=A4(PersInHH,RoomsNum,Tenure)
 240        continue
 230     continue
 220  continue

!      write(6,'(i8)') T22(1) 
      write(6,'(i8)') Sum(Tjm22(1:196))      
      write(6,'(4i8)') (Tjm22(cell), cell=1,196)

!     5.  Convert T14 into A5(Age,EconPrim,Ltill) and then into Tjm14
!     NOTE: LtIll is 'implicit', since table gives counts only for those
!     suffering from LtIll

      cell=12
      do 250, EconPrim=1,10
         cell=cell+1
         do 260, Age=1,4
            cell=cell+1
            A5(Age,EconPrim)=T14(cell)
 260     continue
         cell=cell+1
         if (EconPrim .eq. 6) cell=cell+6
 250  continue

      cell=0
      do 270, Age=1,4
         do 280, EconPrim=1,10
            cell=cell+1
            Tjm14(cell)=A5(Age,EconPrim)
 280     continue
 270  continue

!      write(6,'(i8)') T14(1) 
            write(6,'(i8)') Sum(Tjm14(1:40))
      write(6,'(4i8)') (Tjm14(cell), cell=1,40)

!     6.  Convert T29 into Tjm29
!     NOTE: HHComp is a 'derived' keyterm, based on NDepNo x DepNoP

      cell=8
      do 290, HHComp=1,7
         cell=cell+1
         Tjm29(HHComp)=T29(cell)
         cell=cell+7
 290  continue

!      write(6,'(i8)') T29(1) 
            write(6,'(i8)') Sum(Tjm29(1:7))
      write(6,'(4i8)') (Tjm29(cell), cell=1,7)

!     7.  Convert T74 into A7(Age,Occpatn,Sex) and then into Tjm74
!     T74 is a 10% sample, so multiplied by 10 to give 100% equivalent
!     NOTE: Table gives figures for employees and self-employed only
!     NOTE: Last age group is based on gender retirement ages

      cell=10
      do 300, Occpatn=1,10
         do 310, Sex=1,2
            do 320, Age=1,5
               cell=cell+1
               A7(Age,Occpatn,Sex)=T74(cell)*10
 320        continue
 310     continue
 300  continue

      cell=0
      do 330, Age=1,5
         do 340, Occpatn=1,10
            do 350, Sex=1,2
               cell=cell+1
               Tjm74(cell)=A7(Age,Occpatn,Sex)
 350        continue
 340     continue
 330  continue

      total=0
      do 360, cell=1,10
         total=total+T74(cell)
 360  continue

!      write(6,'(i8)') total*10 
            write(6,'(i8)') Sum(Tjm74(1:100))
      write(6,'(4i8)') (Tjm74(cell), cell=1,100)

!     8.  Convert T86 into A8(Tenure,SEGHOH), and then into Tjm86
!     T86 is a 10% sample, so multiplied by 10 to give 100% equivalent
!     NOTE: counts for head of household only

!**     use data from synthetic reconstruction 
!       (ward distribution constrained by ed tenure marginal)  
        goto 987

      cell=13
      do 370, SEGHOH=1,19
         cell=cell+1
         do 380, tenure=1,4
            cell=cell+1
            A8(Tenure,SEGHOH)=(T86(cell)*10)
 380     continue
         cell=cell+8
 370  continue

      cell=0
      do 385, tenure=1,4
         do 387, SEGHOH=1,19
            cell=cell+1
            Tjm86(cell)=A8(Tenure,SEGHOH)
 387     continue
 385  continue

      total=0
      do 390, cell=2,5
         total=total+T86(cell)
 390  continue

!      write(6,'(i8)') total*10
            write(6,'(i8)') Sum(Tjm86(1:76))
      write(6,'(4i8)') (Tjm86(cell), cell=1,76)

!**   -------------------------------------------------------
 987  continue
!      SumA8=0
!      do i=1,Nk
        read(5,*) edid
        if (edid(5:6) == edcode(5:6)) then
                do SEGHOH=1,19    
                read(5,*) A8(1:4,SEGHOH)
                enddo        
        else
                write(*,*) 'edid not eq. edcode  ', edid,edcode 
                goto 999
        endif 
      
 !     SumA8(1:4,1:19)=SumA8(1:4,1:19)+A8(1:4,1:19)              ! sum of Nk
      
!      enddo

      cell=0
      do tenure=1,4
         do SEGHOH=1,19
            cell=cell+1
!            RTjm86(cell)=real(SumA8(Tenure,SEGHOH))/real(Nk)    ! divided by Nk
            Tjm86(cell)=A8(Tenure,SEGHOH)
        enddo
      enddo  
         
!         CALL ROUNDING_MC(76,noofh,RTjm86,Tjm86)
!     write(6,*) '------------------------------------------- S86'              
      write(6,'(i8)') Sum(Tjm86(1:76))           
      write(6,'(4i8)') (Tjm86(cell), cell=1,76)        
      
      WardTjm86(1:76)=WardTjm86(1:76)+Tjm86(1:76)                   ! agg. to ward                                  

!*    9.  Convert T39 into A9(Age,MarStatt,Sex) and then into Tjm39

      cell=7                          ! start from cell 7+1+1+1=10
      do 410, Age=1,7
         cell=cell+1
         do 420, Sex=1,2
            cell=cell+1
            do 430, MarStatt=1,2
               cell=cell+1
               A9(Age,MarStatt,Sex)=T39(cell)
 430        continue
 420     continue
 410  continue

      cell=0
      do 440,Age=1,7
         do 450, MarStatt=1,2
            do 460, Sex=1,2
               cell=cell+1
               Tjm39(cell)=A9(Age,MarStatt,Sex)
 460        continue
 450     continue
 440  continue

!      write(6,'(i8)') T39(1)
            write(6,'(i8)') Sum(Tjm39(1:28))
      write(6,'(4i8)') (Tjm39(cell), cell=1,28)
      
!*    10. Convert T34 into A10(EconPrim,MarStatt,Sex) and then into Tjm34

      cell=12
      do 550, EconPrim=1,11               ! S34 order EconPrim,Sex,Marstatt
         cell=cell+1
         do 560, Sex=1,2
              do 570, Marstatt=1,2
                cell=cell+1
                A10(EconPrim,Marstatt,Sex)=T34(cell)
 570          continue                              
 560     continue
         cell=cell+1
         if (EconPrim .eq. 7) cell=cell+6
 550  continue
              
      cell=0
      do 580, EconPrim=1,11
         do 580, Marstatt=1,2 
              do 580, Sex=1,2         
                cell=cell+1
                Tjm34(cell)=A10(EconPrim,Marstatt,Sex)
 580  continue

!      write(6,'(i8)') T34(1)   
            write(6,'(i8)') Sum(Tjm34(1:44))
      write(6,'(4i8)') (Tjm34(cell), cell=1,44)

!*    11. Convert T08 into A11(Age,EconPrim,Sex) and then into Tjm08

      cell=22
      do 650, Sex=1,2                     !S08 order Sex,EconPrim,Age
         do 660, EconPrim=1,11
         cell=cell+1         
              do 670, Age=1,9
                cell=cell+1
                A11(Age,EconPrim,Sex)=T08(cell)
 670          continue                              
         cell=cell+1
         if (EconPrim .eq. 7) cell=cell+11 
 660     continue
      cell=cell+22
 650  continue
      
      cell=0
      do 680, Age=1,9
         do 680, EconPrim=1,11
              do 680, Sex=1,2         
                cell=cell+1
                Tjm08(cell)=A11(Age,EconPrim,Sex)
 680  continue

!**   scaled down 
      total=Sum(Tjm08(1:198))
      if(total > T34(1)) CALL ROUNDING_MC(198,T34(1),real(Tjm08),Tjm08)
!            write(6,'(2i8)') total, T34(1)               
            write(6,'(i8)') Sum(Tjm08(1:198))
      write(6,'(11i8)') (Tjm08(cell), cell=1,198) 

!*    12. Convert T49 into A12(EthGroup,Tenure) and then into Tjm49

      cell=21
      do 750, Tenure=1,4                     !S49 order Tenure,EthGroup
          cell=cell+1    
              do 770, EthGroup=1,4
                cell=cell+1
                A12(EthGroup,Tenure)=T49(cell)
 770          continue                              
         cell=cell+2
 750  continue
      
      cell=0
      do 780, EthGroup=1,4
         do 780, Tenure=1,4 
                cell=cell+1
                Tjm49(cell)=A12(EthGroup,Tenure)
 780  continue
!      write(6,'(i8)') T49(1)  
                  write(6,'(i8)') Sum(Tjm49(1:16))
      write(6,'(4i8)') (Tjm49(cell), cell=1,16) 

!*    13. Convert T06 into A13(Age,EthGroup) and then into Tjm06

      cell=36
      do 850, Age=1,5                     !S06 order Age,EthGroup
          cell=cell+1    
              do 870, EthGroup=1,10
                cell=cell+1
                A13(Age,EthGroup)=T06(cell)
 870          continue                              
         cell=cell+1
 850  continue
      
      cell=0
      do 880, Age=1,5
         do 880, EthGroup=1,10
                cell=cell+1
                Tjm06(cell)=A13(Age,EthGroup)
 880  continue 

!** 
      total=Sum(Tjm06(1:50))
      if(total > T01(65)) CALL ROUNDING_MC(50,T01(65),real(Tjm06),Tjm06)
!            write(6,'(2i8)') Total, T01(65),T01(64),T01(68)  
            write(6,'(i8)') Sum(Tjm06(1:50))
      write(6,'(10i8)') (Tjm06(cell), cell=1,50)
                                                  
!*    14. Convert T09 into A14(EconPrim,EthGroup,Sex) and then into Tjm09

      cell=12
      do 950, Sex=1,2                     !S09 order Sex,EconPrim,EthGroup
         do 960, EconPrim=1,3
         cell=cell+1         
              do 970, EthGroup=1,4
                cell=cell+1
                A14(EconPrim,EthGroup,Sex)=T09(cell)
 970          continue                              
         cell=cell+1
 960     continue
      cell=cell+6
 950  continue

!***  As Economically Acitve counts include Unemployed counts. To avoid the 
!       problem of mapping, the unemployed counts is excluded in the ecomomically
!       active figures 

      do Sex=1,2; do EthGroup=1,4
                if (A14(1,EthGroup,Sex)>= A14(2,EthGroup,Sex)) then  ! should be   
                A14(1,EthGroup,Sex)=A14(1,EthGroup,Sex)-A14(2,EthGroup,Sex)
                else                                           ! maybe due +1 -1
                A14(1,EthGroup,Sex)=0
                endif
      enddo; enddo
                                              
      cell=0
      do 980, EconPrim=1,3
         do 980, EthGroup=1,4
              do 980, Sex=1,2         
                cell=cell+1
                Tjm09(cell)=A14(EconPrim,EthGroup,Sex)
 980  continue 
 
 !**   scaled down 
      total=Sum(Tjm09(1:24))
      if(total > T34(1)) CALL ROUNDING_MC(24,T34(1),real(Tjm09),Tjm09)
!            write(6,'(2i8)') T09(1), T34(1)               
            write(6,'(i8)') Sum(Tjm09(1:24))
      write(6,'(2i8)') (Tjm09(cell), cell=1,24)

!*    15. Convert T43 into A15(EthGroup,HHComp) and then into Tjm43

      cell=6
      do 910, HHComp=1,2               ! S43 order HHComp,EthGroup
         cell=cell+1
         do 920, EthGroup=1,4
                cell=cell+1
                A15(EthGroup,HHComp)=T43(cell)
 920          continue                              
         cell=cell+1
 910  continue
      
      cell=0
      do 930, EthGroup=1,11
         do 930, HHComp=1,2       
                cell=cell+1
                Tjm43(cell)=A15(EthGroup,HHComp)
 930  continue

!      write(6,'(i8)') T43(1) 
            write(6,'(i8)') Sum(Tjm43(1:8))
      write(6,'(2i8)') (Tjm43(cell), cell=1,8)
                                                   
!     16.  Convert T42b into A16(Car,HHComp) and then into Tjm42b

      ! store T42 in Atemp
                       
      cell=16
      do HHComp=1,11
         do Car=1,16
            cell=cell+1
            Atemp(Car,HHComp)=T42(cell)
         enddo
      enddo

      do HHComp=1,11
                A16(1,HHComp)=Atemp(15,HHComp)
                A16(3,HHComp)=Atemp(16,HHComp)                                 
                A16(2,HHComp)=Atemp(1,HHComp)-Atemp(15,HHComp)-Atemp(16,HHComp)
                if (A16(2,HHComp) < 0) A16(2,HHComp)=0
      enddo
                
      cell=0
      do Car=1,3
         do HHComp=1,11
            cell=cell+1
            Tjm42b(cell)=A16(Car,HHComp)
         enddo
      enddo  
                  write(6,'(i8)') Sum(Tjm42b(1:33))
      write(6,'(11i8)') (Tjm42b(cell), cell=1,33)
      
!     16.  Read Tjm74b      SAS74_5.dat are in the format of Occpatn by sex

        read(15,*) edid
        if (edid(5:6) == edcode(5:6)) then    
                read(15,*) Tjm74b(1:20)      
        else
                write(*,*) 'table 74 edid not eq. edcode  ', edid,edcode 
                goto 999
        endif 
!     write(6,*) '--------------------------------- 74'             
      write(6,'(i8)') Sum(Tjm74b(1:20))
      write(6,'(2i8)') (Tjm74b(cell), cell=1,20)        
      
      WardTjm74(1:20)=WardTjm74(1:20)+Tjm74b(1:20)                   ! agg. to ward       
                                           
!     Write end of file information

      write(6,*)
      write(6,*) 'NOTE:  ALL SAS TABLE DATA SHOULD BE ARRANGED IN THE'
      write(6,*) '       ORDER USED IN CALCTJM (I.E. ALPHABETICAL'
      write(6,*) '       ORDER), NOT SIMPLY IN THE FORMAT USED IN THE'
      write(6,*) '       OPCS LBS/SAS TABLE LAYOUTS.(except SEG of head)'
      write(6,*)
      write(6,*) 'N.B. Derived keyterms such as HHComp are listed in'
      write(6,*) 'alphabetical order AFTER MetaC91 keyterms'
      write(6,*) '1.   Data from SAS Table S35 (Age by MarStatt by Sex)'
      write(6,*) '2.   Data from SAS Table S42 (Tenure by HHComp)'
      write(6,*) '3.   Data from SAS Table S01 (ResidSta by Sex)'
      write(6,*) '4.   Data from SAS Table S22 (PersInHH by RoomsNum by Tenure)'
      write(6,*) '5.   Data from SAS Table S14 (Age by EconPrim) ((LtIll))'
      write(6,*) '6.   Data from SAS Table S29 (HHComp) ((NDepNo by DepNoP))'
      write(6,*) '7.   Data from SAS Table S74 (Age by Occpatn by Sex)'
      write(6,*) '8.   Data from SAS Table S86 (SEG (Tenure by SEGHOH))'
!*
      write(6,*) '9.   Data from SAS Table S39 (Age by MarStatt by Sex of HOH)'
      write(6,*) '10.  Data from SAS Table S34 (EconPrim by MarStatt by Sex)'
      write(6,*) '11.  Data from SAS Table S08 (Age by EconPrim by Sex)'
      write(6,*) '12.  Data from SAS Table S49 (EthGroup of HOH by Tenure)'
      write(6,*) '13.  Data from SAS Table S06 (Age by EthGroup)'
      write(6,*) '14.  Data from SAS Table S09 (EconPrim by EthGroup by Sex)'
      write(6,*) '15.  Data from SAS Table S43 (EthGroup by HHComp)'
      write(6,*) '16.  Data from SAS Table S42b (Cars by HHComp)'
      write(6,*) '17.  Data from SAS Table S74b (Occup by Sex)'              
      write(6,*)
      write(6,*) 'Note:  Data from 10% tables has been scaled up to 100%'
      write(6,*) '       But not used here, (use SR output)'
      write(6,*)      
      write(6,*) 'edid and edcode should be the same   ', edid,'  ',edcode
      close(6)
              
        wdcode1=wdcode2
      goto 1

  999  continue

!       final ward                
            ! agg. ED table 86&74 to ward level (for ward level comperison)
            open(7,file='e:\Pop91t17\Data\SAS\'//wdcode1//'T86.dat',status='replace')                               
            write(7,'(19i6)') (wardTjm86(cell),cell=1,76)
            write(7,*) wdcode1  
                        
            open(9,file='e:\Pop91t17\Data\SAS\'//wdcode1//'T74.dat',status='replace')                               
            write(9,'(2i8)') (wardTjm74(cell),cell=1,20)
            write(9,*) wdcode1            
               
            ! output WDlist
            write(3,'(a4,i10)') wdcode1, noofed

      stop
      end   
     
  
!_____________________________________________________________________________________
!      
        SUBROUTINE ROUNDING_MC(N,M,A,IA)
!-------------------------------------------------------------------------------------
!       Turning table A into integer dis IA (1D) with total given by M
!       A adjusted with M is separate into integer and decimal parts and
!       only decimal part is randomly rounded to 1      
!-------------------------------------------------------------------------------------
        
        implicit none
        integer                 :: i,k,N,M,TIA,j
        real, dimension(:)    :: A(N),PA(N),DA(N),P(N)
        integer,dimension(:)   :: IA(N)
        real                   :: T , randm   
!        double precision        :: randm 
                          
        T=0.; IA=0; TIA=0

        if (M==0) goto 10
!       distributing M according to A         
        
        do i=1,N;   T=T+A(i); enddo
        if (T < 0.000001) goto 10  
        
        PA=A*M/T             ! PA is now the dis. total to M
                                                                                                    
!       seperating  PA to the integer and decimal parts
        IA=INT(PA); DA=PA-real(IA)

        PA=0.        
!       turning DA into acc. p PA
        CALL ACCP1(N,DA,PA) 

!        do i=1,N;   TIA=TIA+IA(i); enddo        
        TIA=sum(IA(1:N))
        if (TIA==M) goto 10 
               
        do k=1,M-TIA
                  
                CALL RANDOM_NUMBER (randm)

        loopk: do i=1,N-1
                if (randm<PA(1)) then
                        IA(1)=IA(1)+1
                        j=1 
                        exit loopk                
                elseif (randm>PA(i) .and. randm<=PA(i+1)) then
                         IA(i+1)=IA(i+1)+1
                         j=i+1                       
                         exit loopk 
                else
                endif               
            enddo loopk
!               
        DA(j)=0.
        CALL ACCP1(N,DA,PA)
                
        enddo    
                   
 10     continue 
        return
        END  

!_____________________________________________________________________________________
!      
        SUBROUTINE ACCP1(N1,A,PA)
!-------------------------------------------------------------------------------------
!       Turning table A into accumulated probability PA (1D)      
!-------------------------------------------------------------------------------------
        
        implicit none
        integer                 :: i,N1
        real, dimension(:,:)    :: A(N1), PA(N1)
        real                   :: T     
                
        T=0.; PA=0.
        
        do i=1,N1;   T=T+A(i); enddo
!        T=SUM(A)
        if (T < 0.000001) goto 10  
        
        PA=A/T             ! PA is now the probabilities
                         
!       turn PA into accumulated probabilities PA
                
                do i=1,N1
                        if (i==1) then 
                                PA(i)=PA(i)
                        else
                                PA(i)=PA(i-1)+PA(i)
                        endif
                enddo 
 10     continue 
        return
        END           