      subroutine analysis(switch,edcode,Nk,maxj,Nm,nooft,E,U)

!       analysis_a.f95 based on analysis.f95 (for comparing with SR results)
!       adjust those tables that inconsistent with the format of SR output
!               table 35 - S35 age 16+ only (excluding children)
!               table 42 - S42 tenure only (excluding HHComp)
!               tables 34&08 - S34&S08 excluding economically active students       

!     This subroutine analyse and report the results over Nk replications
!     giving SAS table counts U for each table and estimated counts E of each run
!     The following measures are calculated:

!     Cell Z-score  
!       Z               : Z-score of individual cell
!       Z1a             : Z-score of individual cell if U increased by 1
!       Z1m             : Z-score of individual cell if U decreased by 1

!     Tabular test
!       MeanTotal       : Mean table total over Nk runs + sdTotal
!       SumZ2ofMean     : Sum Z sq. of Mean 
!       SumZ2           : Sum of Z-score of each run
!       MeanSumZ2       : Mean Sum of Z-score over Nk runs + sdSumZ2      
!       MeanTAE         : Mean table total absolute error over Nk runs + sdTAE
!       MeanRAE         : Mean table relative absolute error over Nk runs + sdRAE
!*      MeanNotFCP1     : Mean % cells not fit over Nk run 
!                               (probability of Z-score>1.96)
!*      MeanNotFCP2     : Mean % cells not fit over Nk run  
!                               (probability of Z,Z1a&Z1m>1.96)
!*      Peakness1       : Peakness index of not fit cell distribution (Z>1.96Z)
!*      Peakness2       : Peakness index of not fit cell distribution (Z,Z1a&Z1m>1.96)

!     Cellular test
!       CellMean        : Mean estimated cell count over Nk runs
!       CellMax         : Maximum estimated cell counte over Nk runs   
!       CellMin         : Minimum estimated cell counte over Nk runs 
!       Top95           : Top of 95% interval 
!       Bottom95        : Bottom of 95% interval
!       ZofMean         : Z-score of estimated cell mean 
!       CellMeanNF      : % of cell mean Z-score > 1.96
!       MeanZ           : Mean cell Z-score over Nk runs       
!       CellNotFit1     : % of cell Z-score > 1.96  over Nk runs (for each cells)
!       CellNotFit2     : % of all cell Z, Z1a and Z1m > 1.96 over Nk runs
!       NotFitCellP1    : 100*(Number of CellNotFit1 > 0)/(Number of table cells)
!       PoorFitCellP1   : 100*(Number of CellNotFit1 > 5)/(Number of table cells)  
!       NotFitCellP2    : 100*(Number of CellNotFit2 > 0)/(Number of table cells)
!       PoorFitCellP2   : 100*(Number of CellNotFit2 > 5)/(Number of table cells)

      implicit none
      integer U(0:maxj,1:nooft), E(1:maxj,1:nooft,1:Nk), maxj
      integer Nm(1:nooft), nooft, Nk
      integer m,n,k,cell,count
      real Z(1:maxj,1:Nk), TotalU, TotalE(1:Nk), MeanTotal, TableTAE(1:Nk),p,t
      real Z1a(1:maxj,1:Nk),Z1m(1:maxj,1:Nk)
      real SumZ2(1:Nk),MeanSumZ2,MeanTAE,ChisqCV(1:nooft),NotFit(1:nooft)
      real CellMean(1:maxj),ZofMean(1:maxj),MeanZ(1:maxj),CellNotFit1(1:maxj),&
                CellNotFit2(1:maxj)
      integer CellMax(1:maxj),CellMin(1:maxj),AE(1:Nk),Top95(1:maxj),Bottom95(1:maxj)
      real SumZ2ofMean,NotFitCellP1,NotFitCellP2, PoorFitCellP1,PoorFitCellP2,&
                 temp,a1,a2                     
      character*6 edcode 
      integer switch(nooft)

      integer  table(17)                                            !*

      real sdTotal, sdTAE, sdRAE, sdSumZ2, sdNotFCP1, sdNotFCP2
      real TableRAE(Nk),MeanRAE,NotFCP(Nk),MeanNotFCP1(19),MeanNotFCP2            
      real CellMeanNF, Peakness1, Peakness2                                 
                        
      Z=0.; Z1a=0.; Z1m=0.; TotalU=0.; TotalE=0.; MeanTotal=0.; TableTAE=0
      SumZ2=0.; MeanTAE=0.; ChisqCV=0.; NotFit=0.; AE=0
            
 !    table:  1 2  3  4  5  6  7  8  9 10 11 12  13 14 15 16 17 
  data table/35,42,01,22,14,29,74,86,39,34,08,49,06,09,43,142,174/
  
                 
                          
!     0.  table-specific 5% critical value (df=no. of cells)
!         (need amended when adding new tables)   
                                  
      do m=1,nooft
                if (Nm(m).eq.6) ChisqCV(m)=12.59               ! S01 
                if (Nm(m).eq.7) ChisqCV(m)=14.07               ! S29    S42a
                if (Nm(m).eq.28) ChisqCV(m)=41.34              ! S39 
                if (Nm(m).eq.40) ChisqCV(m)=55.76              ! S14    S34a
                if (Nm(m).eq.76) ChisqCV(m)=97.43              ! S86
                if (Nm(m).eq.77) ChisqCV(m)=98.48              ! S42           
                if (Nm(m).eq.84) ChisqCV(m)=106.39             ! S35
                if (Nm(m).eq.100) ChisqCV(m)=124.34            ! S74                              
                if (Nm(m).eq.196) ChisqCV(m)=229.66            ! S22              
                if (Nm(m).eq.44) ChisqCV(m)=60.48              ! S34           
                if (Nm(m).eq.198) ChisqCV(m)=231.83            ! S08
                if (Nm(m).eq.16) ChisqCV(m)=26.30              ! S49                              
                if (Nm(m).eq.50) ChisqCV(m)=67.50              ! S06
                if (Nm(m).eq.24) ChisqCV(m)=36.42              ! S09                              
                if (Nm(m).eq.8) ChisqCV(m)=15.15               ! S43
                if (Nm(m).eq.68) ChisqCV(m)=88.25                    ! S35a
                if (Nm(m).eq.180) ChisqCV(m)=212.3                   ! S08a
                if (Nm(m).eq.33) ChisqCV(m)=41.4               ! S42b                              
                if (Nm(m).eq.20) ChisqCV(m)=31.41              ! S74b                                                                                                         
      enddo    

  

      write(5,*)' starting analysis'
      write(14,*)
      write(14,*)' TABULAR TEST RESULTS'
      write(14,*)      
      write(14,*)' EDCODE =', edcode
      write(14,'(a11,I6)')'  Trials =', Nk        
      write(14,*)
      write(14,*)'EDcode Table STotal MTotal Cell',&
                  '  MTAE   MRAE SZ2ofM MeanNF% MSumZ2 SZ2>%',&
                  ' MNFCP1 MNFCP2 Peakn1 Peakn2',&
                  ' NotF1% NotF2% CV' 
      write(13,*)' CELLULAR TEST RESULTS'
      write(13,*)      
      write(13,*)' EDCODE = ', edcode,'  Trials = ', Nk  
      write(13,*)
      
!     analysing and reporting for each table  
                                                                
      do m = 1,nooft
      
        if(switch(m)==0) goto 808                    

!     1.  Calculate Z-scores for each cell and each replication

!     a)  Find Totals of Ujm and Ejmk and TableTAEk, TableRAEk (means and sd)

        TotalU=0.   
        do cell=1,Nm(m)
                TotalU=TotalU+real(U(cell,m))
        enddo
       
        if (nint(TotalU) .eq. 0) then
         write(14,*) 'Table =', m
         write(14,*)
         write(14,*)  'Z-scores cannot be calculated: Sum of Ujm=0'
         goto 800
        endif 
        
        do k=1,Nk      
                TotalE(k)=0.
                TableTAE(k)=0. 
                do cell=1,Nm(m)
                TotalE(k)=TotalE(k)+real(E(cell,m,k))
                TableTAE(k)=TableTAE(k)+abs(U(cell,m)-E(cell,m,k))
                enddo 
        enddo         
!*                
         do k=1,Nk
                 
                if (nint(TotalE(k)) .eq. 0) then
                write(14,*) 'Table =', m, '  Replication =', k
                write(14,*)
                write(14,*)  'Z-scores cannot be calculated: Sum of Ejmk=0'
                goto 800
                endif
        
         TableRAE(k)=TableTAE(k)/TotalE(k)
         enddo        
        
       
!*      Mean total (MeanTotal) and sdTotal 

        MeanTotal=0.
        do k=1,Nk 
                MeanTotal=MeanTotal+TotalE(k)
        enddo
                MeanTotal=MeanTotal/real(Nk)
!*        
                call sdeviation(Nk,TotalE,Meantotal,sdTotal) 

!*       Mean TAE (MeanTAE) and sdTAE
        
        MeanTAE=0.
        do k=1,Nk
                MeanTAE=MeanTAE+TableTAE(k)
        enddo        
                MeanTAE=MeanTAE/real(Nk)
!*        
                call sdeviation(Nk,TableTAE,MeanTAE,sdTAE)                  
                
!*       Mean RAE (MeanRAE) and sdRAE
        
        MeanRAE=0.
        do k=1,Nk
                MeanRAE=MeanRAE+TableRAE(k)
        enddo        
                MeanRAE=MeanRAE/real(Nk)
!*        
                call sdeviation(Nk,TableRAE,MeanRAE,sdRAE)
                                             
                                              
  
!     b)  Find Z-scores, Z1a-scores for (U+1) and Z1m-scores for (U-1,where U>0)
      
      do k=1,Nk
        do cell=1,Nm(m)
         
                t=real(E(cell,m,k))/TotalE(k) 
                p=real(U(cell,m))/TotalU 
                                 
         if (abs(t-p)<0.000001 ) then                           !ie t=p
                Z(cell,k)=0.                                     
         elseif (U(cell,m) .eq. 0)  then
                p=1.0/TotalU  
                Z(cell,k)= t / ((p*(1-p)/TotalE(k)) **0.5 ) 
!*
         elseif (U(cell,m) .eq. nint(TotalU)) then          ! cell count=total
 
!       if cell count = table total Z-score can not be calculated
!       in this case calculating Z as both actual and estimated cell counts take 1
!       the results is approximately Z~=E-V 

                t=real(E(cell,m,k)-1)/TotalE(k) 
                p=real(U(cell,m)-1)/TotalU 
                Z(cell,k)=(t-p)/((p*(1-p)/TotalE(k)) **0.5 )                 
!                Z(cell,k)=((t-p)-abs(t-p)/(t-p)/(2.*TotalE(k))) /      &
!                          ((p*(1-p)/TotalE(k)) **0.5 ) 
  
         else                                                                                                            
                Z(cell,k)=(t-p)/((p*(1-p)/TotalE(k)) **0.5 )
!                Z(cell,k)=((t-p)-abs(t-p)/(t-p)/(2.*TotalE(k))) /      &
!                          ((p*(1-p)/TotalE(k)) **0.5 ) 
         endif
        enddo
      enddo       ! k
      
      ! Z1a
      do k=1,Nk
        do cell=1,Nm(m)
         
                t=real(E(cell,m,k))/TotalE(k) 
                p=real(U(cell,m)+1)/TotalU
                          
         if (abs(t-p)<0.000001) then                !ie t=p
                Z1a(cell,k)=0.
         
         elseif ((U(cell,m)+1)>=TotalU) then         !
                Z1a(cell,k)=Z(cell,k)                  
         else
                Z1a(cell,k)=(t-p)/((p*(1-p)/TotalE(k)) **0.5 )                                               
!                Z1a(cell,k)=((t-p)-abs(t-p)/(t-p)/(2.*TotalE(k))) /      &
!                          ((p*(1-p)/TotalE(k)) **0.5 )          
         endif
        enddo
      enddo       ! k
                        
      ! Z1m
      do k=1,Nk
        do cell=1,Nm(m)
         
                t=real(E(cell,m,k))/TotalE(k) 
            if (U(cell,m) > 0) then 
                p=real(U(cell,m)-1)/TotalU
            else
                Z1m(cell,k)=Z(cell,k)
                goto 300
            endif
                                 
         if (abs(t-p)<0.000001) then                !ie t=p
                Z1m(cell,k)=0.
         else
                if (U(cell,m)-1 .eq. 0)  then
                p=1.0/TotalU  
                Z1m(cell,k)= t / ((p*(1-p)/TotalE(k)) **0.5 ) 
                else 
                Z1m(cell,k)=(t-p)/((p*(1-p)/TotalE(k)) **0.5 )                                       
!                Z1m(cell,k)=((t-p)-abs(t-p)/(t-p)/(2.*TotalE(k))) /      &
!                          ((p*(1-p)/TotalE(k)) **0.5 ) 
                endif          
         endif
    300 continue    
        enddo
      enddo       ! k                                                            
      
!     2.  Tabular test over Nk replications

!     a)  Mean total (MeanTotal)      see above


                
!     b)  Sum Z sq. (SumZ2(k)) and compared with critical chi sq. value
        
        SumZ2=0.
        do k=1,Nk
           do cell=1,Nm(m)     
                SumZ2(k)=SumZ2(k)+ Z(cell,k)**2
           enddo
        enddo 
        
        count=0
        do k=1,Nk
                if (SumZ2(k) > ChisqCV(m)) count=count+1            
        enddo
                NotFit(m)=100*real(count)/real(Nk)
                
!     c)  Mean Sum Z sq. (MeanSumZ2) 

        MeanSumZ2=0.
        do k=1,Nk 
                MeanSumZ2=MeanSumZ2+SumZ2(k)
        enddo
                MeanSumZ2=MeanSumZ2/real(Nk)
        !*        
                call sdeviation(Nk,SumZ2,MeanSumZ2,sdSumZ2)                    
                                                  

!     d) Mean TAE (Mean TAE)    see above 

  
!*    e) MeanNotFC%1     : Mean % cells not fit over Nk run
!        MeanNotFC%2     : Mean % cells not fit over Nk run

        MeanNotFCP1(m)=0.
        do k=1,Nk
                count=0 
                do cell=1,Nm(m)
                if (abs(Z(cell,k)) > 1.96) count=count+1            
                enddo
                NotFCP(k)=100.*real(count)/real(Nm(m))       ! percentage     
        enddo            
                MeanNotFCP1(m)=sum(NotFCP(1:Nk))/real(Nk) 
                
                call sdeviation(Nk,NotFCP,MeanNotFCP1(m),sdNotFCP1) 
                                
        MeanNotFCP2=0.
        do k=1,Nk
                count=0 
                do cell=1,Nm(m)
                if (abs(Z(cell,k)) > 1.96 .and. abs(Z1a(cell,k)) > 1.96 .and.  &
                        abs(Z1m(cell,k)) > 1.96 ) count=count+1            
                enddo
                NotFCP(k)=100.*real(count)/real(Nm(m))       ! percentage     
        enddo            
                MeanNotFCP2=sum(NotFCP(1:Nk))/real(Nk)
                
                call sdeviation(Nk,NotFCP,MeanNotFCP2,sdNotFCP2)                                                                 

!     3.  Cellular test over Nk replications     

!       a) Mean of estimated counts (CellMean)

        CellMean=0.
        do cell=1,Nm(m)
                do k=1,Nk 
                CellMean(cell)=CellMean(cell)+E(cell,m,k)
                enddo
                CellMean(cell)=CellMean(cell)/real(Nk)                  
        enddo
        
!       b) Max and Min of estimated counts (CellMax, CellMin)        
        
        do cell=1,Nm(m)  
                CellMax(cell)=maxval(E(cell,m,1:Nk))
                CellMin(cell)=minval(E(cell,m,1:Nk)) 
        enddo
                
!       c) Top and Bottom of 95% interval of estimated counts (Top95,Bottom95) 

        Top95=0; Bottom95=0
        a1=0.975*(Nk-1.)+1. ;    a2=0.025*(Nk-1.)+1.         

        do cell=1,Nm(m)
        
        ! sort E into ascending order stored in AE(1:Nk) 
                AE(1:Nk)=E(cell,m,1:Nk)                
                do k=1,Nk
                      do n=k+1,Nk
                        if (AE(k) > AE(n)) then
                        temp=AE(n)
                        AE(n)=AE(k)
                        AE(k)=temp
                        endif
                      enddo
                enddo                                                          
        
                Top95(cell)=nint(AE(int(a1))+ &
                        (AE(int(a1)+1)-AE(int(a1)))*(a1-int(a1)))
                Bottom95(cell)=nint(AE(int(a2))+ &
                        (AE(int(a2)+1)-AE(int(a2)))*(a2-int(a2)))
        enddo       

!       d) Z of mean (ZofMean) and Sum Z sq. of mean (SumZ2ofMean)

        do cell=1,Nm(m)
             
                t=CellMean(cell)/TotalU 
                p=real(U(cell,m))/TotalU                
         
         if (abs(t-p)<0.000001) then                !ie t=p
                ZofMean(cell)=0.
                
         elseif (U(cell,m) .eq. nint(TotalU)) then          ! cell count=total
 
!       if cell count = table total Z-score can not be calculated
!       in this case calculating Z as both actual and estimated cell counts take 1
!       the results is approximately Z~=E-V 

                t=(CellMean(cell)-1)/TotalU 
                p=real(U(cell,m)-1)/TotalU 
                ZofMean(cell)=(t-p)/((p*(1-p)/TotalU) **0.5 )
!                ZofMean(cell)=((t-p)-abs(t-p)/(t-p)/(4.*TotalU)) /      &
!                          ((p*(1-p)/TotalU) **0.5 )                                
         elseif (U(cell,m) .eq. 0)  then
                p=1.0/TotalU  
                ZofMean(cell)= t / ((p*(1-p)/TotalU) **0.5 ) 
         else
                ZofMean(cell)=(t-p)/((p*(1-p)/TotalU) **0.5 )                                         
!                ZofMean(cell)=((t-p)-abs(t-p)/(t-p)/(4.*TotalU)) /      &
!                          ((p*(1-p)/TotalU) **0.5 )         
         endif
        
        enddo
        
        
        CellMeanNF=0
                count=0 
                do cell=1,Nm(m)
                if (abs(ZofMean(cell)) > 1.96) count=count+1            
                enddo
                CellMeanNF=100.*real(count)/real(Nm(m))       ! percentage                        
         
        SumZ2ofMean=0
        do cell=1,Nm(m)
                SumZ2ofMean=SumZ2ofMean+ZofMean(cell)*ZofMean(cell)
        enddo
         
!       d) Mean Z (MeanZ) and compared Z with 1.96

        MeanZ=0.
        do cell=1,Nm(m)
                do k=1,Nk 
                MeanZ(cell)=MeanZ(cell)+Z(cell,k)
                enddo
                MeanZ(cell)=MeanZ(cell)/real(Nk)                  
        enddo  

!       e) compared Z (>) with 1.96 giving NotFitCellP1 and PoorFitCellP1

        CellNotFit1=0.                            
        do cell=1,Nm(m)
                count=0
                do k=1,Nk
                if (abs(Z(cell,k)) > 1.96) count=count+1            
                enddo
                CellNotFit1(cell)=100.*real(count)/real(Nk)       ! percentage
        enddo
        
        ! number of not or poor fit cell (if CellNotFit1 > 0 or 5) over total table cells
                count=0
                do cell=1,Nm(m)
                if (CellNotFit1(cell) > 0.000001) count=count+1            
                enddo
                        NotFitCellP1=100.*real(count)/Nm(m)
                count=0
                do cell=1,Nm(m)
                if (CellNotFit1(cell) > 5.) count=count+1            
                enddo                
                        PoorFitCellP1=100.*real(count)/Nm(m)                

!       f)  compared Z, Z1a and Z1m (all >) with 1.96 giving NotFitCellP2&PooroFitCellP2                
        
        CellNotFit2=0. 
        do cell=1,Nm(m)
                count=0
                do k=1,Nk
                if (abs(Z(cell,k)) > 1.96 .and. abs(Z1a(cell,k)) > 1.96 .and.  &
                        abs(Z1m(cell,k)) > 1.96 ) count=count+1            
                enddo
                CellNotFit2(cell)=100.*real(count)/real(Nk)
        enddo
        
        ! number of not or poor fit cell over total table cells
                count=0
                do cell=1,Nm(m)
                if (CellNotFit2(cell) > 0.000001) count=count+1            
                enddo
                        NotFitCellP2=100.*real(count)/Nm(m)
                count=0
                do cell=1,Nm(m)
                if (CellNotFit2(cell) > 5.) count=count+1            
                enddo
                        PoorFitCellP2=100.*real(count)/Nm(m) 
                        
!       g)  Peakness index of not fit distribution = N1/N2
!               N1-total number of not fit (Z>1.96) cells over Nk runs
!               N2-total number of cells that their Z>1.96 occur once or more

                if (MeanNotFCP1(m) < 0.00001) then
                        Peakness1=0.
                else         
                        Peakness1=Nk*MeanNotFCP1(m)/NotFitCellP1                         
                endif
                
                if (MeanNotFCP2 < 0.00001) then
                        Peakness2=0.
                else         
                        Peakness2=Nk*MeanNotFCP2/NotFitCellP2                         
                endif                                                              
                                                                     
800   continue                                 

!     3. output
                  
!       a) Tabular results 

!      write(14,*) ' ActualTotal   MeanTotal   Cells(df)      Trials',&
!                  '     MeanTAE  ChisqCritV  MeanSumZsq  %ofSumZsq>CV'  
      
      write(14,50)edcode,table(m),TotalU,MeanTotal,Nm(m),&
                      MeanTAE,MeanRAE,SumZ2ofMean,CellMeanNF,MeanSumZ2, NotFit(m),&
                      MeanNotFCP1(m),MeanNotFCP2,Peakness1,Peakness2,  &
                      NotFitCellP1,NotFitCellP2,ChisqCV(m)
      write(14,60) edcode,Table(m),sdTotal, sdTAE, sdRAE, sdSumZ2, &
                        sdNotFCP1, sdNotFCP2                      

!       b) Cellular results 

      write(13,*) edcode 
      write(13,'(a20,I3)'     ) ' Table  = ', table(m)
      write(13,*)            
      write(13,'(a20,199I7)'  ) ' Actual count       ', U(1:Nm(m),m)
      write(13,'(a20,199f7.2)') ' Mean synthetic     ', CellMean(1:Nm(m))      
      write(13,'(a20,199I7)'  ) ' Maximum            ', CellMax(1:Nm(m))
      write(13,'(a20,199I7)'  ) ' Minimum            ', CellMin(1:Nm(m))
      write(13,'(a20,199I7)'  ) ' Topof95%interval   ', Top95(1:Nm(m))
      write(13,'(a20,199I7)'  ) ' Bottomof95%intvl   ', Bottom95(1:Nm(m))      
      write(13,'(a20,199f7.3)') ' Z of Mean          ', ZofMean(1:Nm(m))           
      write(13,'(a20,199f7.3)') ' Mean Z             ', MeanZ(1:Nm(m))     
      write(13,'(a20,199f7.1)') ' % of |Z|>1.96      ', CellNotFit1(1:Nm(m))
      write(13,'(a20,199f7.1)') ' %of|Z&Z1a&Z1m|>1.96', CellNotFit2(1:Nm(m))      
      write(13,'(a20,2f7.1)'  ) ' Not&PoorFitCellP1 %', NotFitCellP1,PoorFitCellP1
      write(13,'(a20,2f7.1)'  ) ' Not&PoorFitCellP2 %', NotFitCellP2,PoorFitCellP2
      write(13,*)          

 808  continue  
      enddo  ! m    
      
!       c) Actual and estimated counts               
!         only print those tables for comparing with SR approach
!         table 86, 39, 49, 35, 42, 34, 08

      
      write (10,*) edcode,Nk
          
      do m=1,nooft
        
        if(switch(m)==0) goto 909         
        write(10,*)      
        write(10,*) table(m), Nm(m)
        write(10,*)
        write(10,'(199I4)') U(1:Nm(m),m)
        write(10,*)
        do k=1,Nk; write(10,'(199I4)') E(1:Nm(m),m,k); enddo
        write(10,*) 
 909  continue      
      enddo
        write(10,*)
        write(10,*)'    NOTE:   DATA ARE IN THE FOLLOWING ORDER'
        write(10,*)'            edcode, no of runs'      
        write(10,*)'            table no., table cells'      
        write(10,*)'            SAS counts' 
        write(10,*)'            Estimates for each runs'

 
   50   format(/1x,a6,2x,i3,f8.1,f7.1,i5,f6.1,f7.3,f7.1,f8.1,f6.1,f6.1,2f7.3,6f7.1)
   60   format( 1x,a6,2x,i3,8x,  f7.2,5x,f6.2,f7.3,15x,      f6.2,6x,2f7.2)
!   100  format(20x,199i7)           
   
      return
      end   
      
      
      subroutine sdeviation(N,X,meanX,sd)
      
!     calculating standard diviation for arry X(N)
      
      integer N, i
      real sd, meanX, X(N)
      
      sd=0.
      do i=1,N
                sd=sd+(X(i)-meanX)**2
      enddo
                sd=(sd/N)**0.5
                
      return
      end        
      
      
      
