      subroutine calcFjm(switch,maxj,Nm,nooft,U,F)

!--------------------------------------------------------------------------------
!       calculate the Factor Fjm (the constant part of RSumZm2) 
!       
!       RSumZm2=Sum[Fj(Tj-Uj)**2]       ! relative Sum of Zm sq.
!       where:
!       Fj=1/[Chisq*Uj(1-Uj/TotalU)]    Uj /=0, TotalU /=0
!       Fj=1/Chisq                      Uj =0, TotalU =0
!       
!--------------------------------------------------------------------------------

      implicit none
      integer U(0:maxj,1:nooft),maxj
      integer Nm(1:nooft), nooft, switch(nooft)
      integer m,cell
      real F(1:maxj,1:nooft), TotalU,p,ChisqCV(1:nooft), weight(1:nooft)

      F=0.  
                        
!       the weighting factors allow user to achieve better fit for the tables 
!       interested, also particular large tables tern to have higher RSSZ:
!       S22 and S08 have near 200 cells, so we may wish to give these table 
!       more weight          

      weight=1.   ! equal weight
                                                                                                                                                                                                                                                                                                                                                                                                
      do m=1,nooft

!                if (Nm(m).eq.196) weight(m)=1.5            ! S22                       
                if (Nm(m).eq.198) weight(m)=2.0            ! S08 
                if (Nm(m).eq.196) weight(m)=2.0            ! S22
!                if (Nm(m).eq.84) weight(m)=1.4            ! S35
!                if (Nm(m).eq.77) weight(m)=1.4            ! S42a
!                if (Nm(m).eq.76) weight(m)=1.4            ! S42a                                                                                                                                                                                 
      enddo               

! I   table-specific 5% critical value (df=no. of cells)
!         (need amended when adding new tables)   
                                  
      do m=1,nooft
                if (Nm(m).eq.6) ChisqCV(m)=12.59               ! S01 
                if (Nm(m).eq.7) ChisqCV(m)=14.07               ! S29    S42a
                if (Nm(m).eq.28) ChisqCV(m)=41.34              ! S39 
                if (Nm(m).eq.40) ChisqCV(m)=55.76              ! S14    S34a
                if (Nm(m).eq.76) ChisqCV(m)=97.43              ! S86
                if (Nm(m).eq.77) ChisqCV(m)=98.48              ! S42           
                if (Nm(m).eq.84) ChisqCV(m)=106.39             ! S35
                if (Nm(m).eq.100) ChisqCV(m)=124.34            ! S74                              
                if (Nm(m).eq.196) ChisqCV(m)=229.66            ! S22              
                if (Nm(m).eq.44) ChisqCV(m)=60.48              ! S34           
                if (Nm(m).eq.198) ChisqCV(m)=231.83            ! S08
                if (Nm(m).eq.16) ChisqCV(m)=26.30              ! S49                              
                if (Nm(m).eq.50) ChisqCV(m)=67.50              ! S06
                if (Nm(m).eq.24) ChisqCV(m)=36.42              ! S09                              
                if (Nm(m).eq.8) ChisqCV(m)=15.15               ! S43
                if (Nm(m).eq.68) ChisqCV(m)=88.25                    ! S35a
                if (Nm(m).eq.180) ChisqCV(m)=212.3                   ! S08a
                if (Nm(m).eq.33) ChisqCV(m)=41.4               ! S42b                              
                if (Nm(m).eq.20) ChisqCV(m)=31.41              ! S74b                                                                                                         
      enddo
          
                
! II   calculating Fjm for each table  
                                                                
      do m = 1,nooft
      
        if (switch(m)==0) goto 808                    

!     a)  Totals of Ujm (if totalU <= 1, F=1/Chhisq)

        TotalU=0.   
        do cell=1,Nm(m)
                TotalU=TotalU+real(U(cell,m))
        enddo
       
        if (nint(TotalU) <= 1) then
         
         do cell=1,Nm(m)
                F(cell,m)=1./ChisqCV(m)       
         enddo
         goto 808
                           
        endif
  
!     b)  Fjm
      
        do cell=1,Nm(m)
         

         if (U(cell,m) .eq. 0)  then                         ! zero cell
         
                F(cell,m)=1./ChisqCV(m)
                          
         elseif (U(cell,m) .eq. nint(TotalU)) then          ! cell count=total 
         
                F(cell,m)=1./ChisqCV(m)
                                         
         else   
                p=real(U(cell,m))/TotalU 
                F(cell,m)=1./(ChisqCV(m)*real(U(cell,m))*(1-p))      

         endif 
         
        enddo        
                                                                                                                                                                                                                    
 808  continue 

        do cell=1,Nm(m) 
                F(cell,m)=F(cell,m)*weight(m)
        enddo
        
      enddo  ! m    
                                      
      return
      end   

      
      
      
